# Contributing to WebSweep development

Thank you for considering contributing to WebSweep. Below we provide some guidelines for contributing:

* Reporting a bug
* Suggesting a new feature to the package
* Contributing code

## Reporting a bug

If you found a bug in WebSweep, we would love to know more about it. Please let us know about this problem by [opening an issue](https://github.com/sodascience/websweep/issues/new/choose).

The most important thing to include in your new issue is a minimal reproducible example that we can use to verify your problem and understand its root cause.

For more information about issues, please refer to the official [GitHub guides](https://guides.github.com/features/issues)!

## Suggesting a new feature to WebSweep

We are very interested in hearing your suggestions in regards to the development of new WebSweep features. Let us know about what you think we should add next by [opening a new issue](https://github.com/sodascience/websweep/issues/new/choose).

## Contributing code

To contribute code to WebSweep, you can follow these three steps:

1. Create a branch and make your changes
2. Push the branch to GitHub and issue a [Pull Request (PR)](https://github.com/sodascience/websweep/compare)
3. Discuss with us the pull request and iterate of eventual changes

You can read more about pull requests [using GitHub's official documentation](https://docs.github.com/en/github/collaborating-with-pull-requests/proposing-changes-to-your-work-with-pull-requests/about-pull-requests).
